;;; bandali-theme.el --- bandali's custom theme setup  -*- lexical-binding: t; -*-

;; Copyright (C) 2018-2020  Amin Bandali

;; Author: Amin Bandali <bandali@gnu.org>
;; Keywords: faces

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; My custom theme setup.

;;; Code:

(with-eval-after-load 'package
  (require 'refinery-theme)
  (load-theme 'refinery t))

;; (require 'smart-mode-line)
;; ;; thanks, but no thanks; don't make fixed-width fills.
;; (defun sml/fill-for-buffer-identification nil "")
;; (setq sml/theme 'respectful)
;; (let ((sml/no-confirm-load-theme t))
;;   (sml/setup)
;;   (smart-mode-line-enable))

;; (require 'minions)
;; (minions-mode)

(defvar b/org-mode-font-lock-keywords
  '(("[ \t]*\\(#\\+\\(BEGIN\\|END\\|begin\\|end\\)_\\(\\S-+\\)\\)[ \t]*\\([^\n:]*\\)"
      (1 '(:foreground "#5a5b5a" :background "#292b2b") t) ; directive
      (3 '(:foreground "#81a2be" :background "#292b2b") t) ; kind
      (4 '(:foreground "#c5c8c6") t)))                     ; title
  "For use with the `doom-tomorrow-night' theme.")

(eval-when-compile
  (declare-function exwm-systemtray--refresh "exwm-systemtray")
  (declare-function erc-hl-nicks-reset-face-table "erc-hl-nicks"))

(defun b/lights-on ()
  "Enable my favourite light theme."
  (interactive)
  (mapc #'disable-theme custom-enabled-themes)
  (load-theme 'refinery t)
  (font-lock-remove-keywords
   'org-mode b/org-mode-font-lock-keywords)
  (when (featurep 'exwm-systemtray)
    (exwm-systemtray--refresh)))

(defun b/lights-off ()
  "Go dark."
  (interactive)
  (mapc #'disable-theme custom-enabled-themes)
  (load-theme 'refinery-dark t)
  (font-lock-add-keywords
   'org-mode b/org-mode-font-lock-keywords t)
  (when (featurep 'exwm-systemtray)
    (exwm-systemtray--refresh)))

(global-set-key (kbd "C-c t d") #'b/lights-off)
(global-set-key (kbd "C-c t l") #'b/lights-on)

(provide 'bandali-theme)
;;; bandali-theme.el ends here
